@@ -1,10 +1,10 @@
 ########################################################################################################################
 # Package: PQLseq
-# Version: 1.1
-# Date   : 2018-08-05
+# Version: 1.2
+# Date   : 2020-05-01
 # Title  : Heritability Estimation and Differential Analysis with Generalized Linear Mixed Models in Large-Scale Genomic Sequencing Studies
 # Authors: Shiquan Sun, Jiaqiang Zhu, and Xiang Zhou
-# Contact: shiquans@umich.edu and jiaqiang@umich.edu 
+# Contact: jiaqiang@umich.edu 
 #          University of Michigan, Department of Biostatistics
 ########################################################################################################################
 
@@ -106,7 +106,7 @@ pqlseq <- function(RawCountDataSet, Phenotypes, Covariates=NULL, RelatednessMatr
 			if(verbose) {cat(paste("NO. Gene = ",iVar,"\n"))}
     
 			tmpRelatednessMatrix <- RelatednessMatrix
-			if(class(tmpRelatednessMatrix) == "matrix") {
+			if(is(tmpRelatednessMatrix,"matrix")) {
 				tmpRelatednessMatrix <- tmpRelatednessMatrix[idx, idx]
 			}else {
 				for(ik in seq_len(length(tmpRelatednessMatrix)) ) {tmpRelatednessMatrix[[ik]] <- tmpRelatednessMatrix[[ik]][idx, idx]}
@@ -207,7 +207,7 @@ pqlseq <- function(RawCountDataSet, Phenotypes, Covariates=NULL, RelatednessMatr
 			if(!redflag){
       
 				tmpRelatednessMatrix <- RelatednessMatrix
-				if(class(tmpRelatednessMatrix) == "matrix") {
+				if(is(tmpRelatednessMatrix,"matrix")) {
 					tmpRelatednessMatrix <- tmpRelatednessMatrix[idx, idx]
 				}else {
 					for(ik in seq_len(length(tmpRelatednessMatrix)) ) {
@@ -324,7 +324,7 @@ PQLseq.AI <- function(model0, RelatednessMatrix, tau = rep(0, length(Relatedness
 
 		P <- try(Hinv - tcrossprod(tcrossprod(HinvX, chol2inv(chol( XHinvX ))), HinvX))
 	
-		if(class(P) == "try-error"){
+		if(is(P,"try-error")){
 			stop("Error in P matrix calculation!")
 		}
 
